package com.rshy.project.hy.server;

import cn.hutool.http.HttpUtil;
import com.alibaba.fastjson.JSONObject;
import com.github.rholder.retry.Retryer;
import com.github.rholder.retry.RetryerBuilder;
import com.github.rholder.retry.StopStrategies;
import com.github.rholder.retry.WaitStrategies;
import com.google.common.base.Predicates;
import com.rshy.project.hy.baseRe.BaseException;
import com.rshy.project.hy.baseRe.Ret;
import com.rshy.project.hy.entity.RshyJk;
import com.rshy.project.hy.server.param.RshyParam;
import com.rshy.project.hy.server.vo.RshyTypeVo;
import com.rshy.project.hy.server.vo.RshyVo;
import com.rshy.project.hy.server.vo.RshyWarningVo;
import com.rshy.project.hy.service.RshyJkService;
import com.sun.org.apache.xpath.internal.SourceTree;
import lombok.extern.log4j.Log4j;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.apache.commons.lang3.concurrent.BasicThreadFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.scheduling.annotation.Async;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;
import org.springframework.util.SocketUtils;
import org.springframework.web.client.RestTemplate;

import java.io.IOException;
import java.math.BigDecimal;
import java.util.*;
import java.util.concurrent.*;
import java.util.stream.Collectors;

/**
 * @ProjectName: rshy
 * @Package: com.rshy.project.hy.server
 * @ClassName: RshyServer
 * @Author: shihongbo
 * @Description:
 * @Date: 2022/3/1 17:37
 * @Version: 1.0
 */
@Component
@Slf4j
public class RshyServer {

    @Value("${base.url}")
    private String baseUrl;

    @Autowired
    private RshyJkService rshyJkService;


    ExecutorService executorService = Executors.newCachedThreadPool();


    private List<RshyJk> getJkList() {
        return rshyJkService.getRshyJkAll();
    }


    /***
     * 核验接口
     * @param rshyParam
     * @return
     */
    public RshyVo getRshyInfo(RshyParam rshyParam) {
        if (Objects.isNull(rshyParam) || (StringUtils.isBlank(rshyParam.getSfzh()) && StringUtils.isBlank(rshyParam.getBarCode()) && StringUtils.isBlank(rshyParam.getXm()))) {
            System.out.println("请求参数为空"+rshyParam);
            return new RshyVo();
        }
        System.out.println("请求参数"+rshyParam);
        RshyVo moreHttpApi = getMoreHttpApi(rshyParam);
        log.error("返回总参数{}",moreHttpApi);
        System.out.println("返回总参数"+moreHttpApi);
        return moreHttpApi;
    }


    private RshyVo getMoreHttpApi(RshyParam rshyParam) {
        List<RshyTypeVo> returnMap = new CopyOnWriteArrayList<>();
        RshyVo rshyVo = new RshyVo();
        List<RshyJk> jkList = getJkList();
        if (StringUtils.isNotBlank(rshyParam.getBarCode())) {
            List<RshyJk> jkm = jkList.stream().filter(e -> e.getHyType().equals("pctjkm")).collect(Collectors.toList());
            System.out.println("进入获取健康码");

            Map<String,String> stringMap = null;
            try {
                stringMap = getPctjkm(rshyParam.getBarCode(),jkm.get(0));
            } catch (Exception e) {
                e.printStackTrace();
                return rshyVo;
            }
            if (Objects.isNull(stringMap)) {
                return rshyVo;
            }
            System.out.println("健康码信息"+stringMap);
            rshyParam.setSfzh(stringMap.get("id_num"));
            rshyParam.setXm(stringMap.get("user_name"));
        }
        try {
            jkList.forEach(url -> executorService.submit(() -> {
                try {
                    returnMap.add(getHttp(rshyParam,url));
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }));
            List<RshyWarningVo> rshyWarningVoList = new ArrayList<>();
            StringBuilder stringBuilder = new StringBuilder();
            RshyWarningVo rshyWarningVoByAll = null;
            executorService.awaitTermination(4, TimeUnit.SECONDS);
            String sfzh = "";
            String xm = "";
            String xb = "";
            if (CollectionUtils.isEmpty(returnMap)) {
                return rshyVo;
            }
            System.out.println("返回map"+returnMap);
            log.error("返回map{}",returnMap);
            for (int i = 0;i< returnMap.size();i++) {
                //在逃人员
                if ("pctzt".equals(returnMap.get(i).getType()) && Objects.nonNull(returnMap.get(i).getMap())) {
                    rshyVo.setPass(0);
                    Map<String, String> map = returnMap.get(i).getMap();
                    rshyVo.setKind(map.get("ztrylxmc"));
                    rshyVo.setWarning("在逃人员:"+map.get("jyaq"));
                    rshyVo.setTts("核验不通过");
                    rshyVo.setDisplayMsg("核验不通过");
                    rshyVo.setXm(map.get("xm"));
                    rshyVo.setSfzh(map.get("zjhm"));
                    break;
                }
                rshyWarningVoByAll = new RshyWarningVo();
                switch (returnMap.get(i).getType()) {
                    case "pctdfk":
                        if (Objects.nonNull(returnMap.get(i).getMap())) {
                            Map<String, String> map = returnMap.get(i).getMap();
                            rshyWarningVoByAll.setDescription(map.get("jyaq"));
                            rshyWarningVoByAll.setTitle("打防控记录");
                            stringBuilder.append("打防控");
                            rshyWarningVoList.add(rshyWarningVoByAll);
                            rshyVo.setTts("核验通过");
                            sfzh = map.get("zjhm");
                            xm = map.get("xm");
                        }
                        break;
                    case "pctjsry":
                        if (Objects.nonNull(returnMap.get(i).getMap())) {
                            Map<String, String> map = returnMap.get(i).getMap();
                            rshyWarningVoByAll.setDescription(map.get("jyaq"));
                            rshyWarningVoByAll.setTitle("监所人员记录");
                            rshyWarningVoList.add(rshyWarningVoByAll);
                            rshyVo.setTts("核验通过");
                            stringBuilder.append("监所人员");
                            sfzh = map.get("zjhm");
                            xm = map.get("xm");
                        }
                        break;
                    case "pctxdry":
                        if (Objects.nonNull(returnMap.get(i).getMap())) {
                            Map<String, String> map = returnMap.get(i).getMap();
                            rshyWarningVoByAll.setDescription(map.get("xdcsmc"));
                            rshyWarningVoByAll.setTitle("吸毒人员记录");
                            rshyWarningVoList.add(rshyWarningVoByAll);
                            stringBuilder.append("吸毒人员");
                            rshyVo.setTts("核验通过");
                            sfzh = map.get("zjhm");
                            xm = map.get("xm");
                        }
                        break;
                    case "pctqkry":
                        if (Objects.nonNull(returnMap.get(i).getMap())) {
                            Map<String, String> map = returnMap.get(i).getMap();
                            rshyWarningVoByAll.setDescription(map.get("lsqkqk"));
                            rshyWarningVoByAll.setTitle("前科人员记录");
                            rshyWarningVoList.add(rshyWarningVoByAll);
                            stringBuilder.append("前科人员");
                            rshyVo.setTts("核验通过");
                            sfzh = map.get("zjhm");
                            xm = map.get("xm");
                        }
                        break;
                    case "pctjkm":
                        if (Objects.nonNull(returnMap.get(i).getMap())) {
                            Map<String, String> map = returnMap.get(i).getMap();
                            rshyVo.setHealthCode(map.get("COLOR_CODE_LABEL"));
                            rshyVo.setTts("核验通过");
                            sfzh = map.get("id_num");
                            xm = map.get("user_name");
                        }
                        break;
                    case "pctzfba":
                        if (Objects.nonNull(returnMap.get(i).getMap())) {
                            Map<String, String> map = returnMap.get(i).getMap();
                            rshyWarningVoByAll.setDescription(map.get("ajmc"));
                            rshyWarningVoByAll.setTitle("执法办案记录");
                            rshyWarningVoList.add(rshyWarningVoByAll);
                            stringBuilder.append("执法办案");
                            rshyVo.setTts("核验通过");
                            sfzh = map.get("zjhm");
                            xm = map.get("ryxm");
                        }
                        break;
                    case "pctzdry":
                        if (Objects.nonNull(returnMap.get(i).getMap())) {
                            Map<String, String> map = returnMap.get(i).getMap();
                            rshyWarningVoByAll.setDescription(map.get("ajlbmc"));
                            rshyWarningVoByAll.setTitle("重点人员");
                            rshyWarningVoList.add(rshyWarningVoByAll);
                            stringBuilder.append("重点人员");
                            rshyVo.setTts("核验通过");
                            sfzh = map.get("zjhm");
                            xm = map.get("xm");
                        }
                        break;
                    default:
                        break;
                }
                if (CollectionUtils.isEmpty(rshyWarningVoList)) {
                    rshyVo.setPass(2);
                    rshyVo.setDisplayMsg("核验通过");
                } else {
                    rshyVo.setPass(1);
                    System.out.println("组装结果"+rshyWarningVoList);
                    RshyWarningVo rshyWarningVo = rshyWarningVoList.get(0);
                    rshyVo.setWarning(rshyWarningVo.getTitle()+":"+rshyWarningVo.getDescription());
                    rshyVo.setKind(stringBuilder.toString());
                    rshyVo.setDisplayMsg("核验通过");
                }
                rshyVo.setSfzh(sfzh);
                rshyVo.setXm(xm);
            }

        } catch (Exception e) {
            e.printStackTrace();
        }
        return rshyVo;
    }




    /***
     * 请求第三方接口
     * @param rshyParam
     * @param type
     * @return
     * @throws IOException
     */
    private RshyTypeVo getHttp(RshyParam rshyParam, RshyJk rshyJk) throws IOException {
        Map<String, String> map = new ConcurrentHashMap<>();
        RshyTypeVo rshyTypeVo = new RshyTypeVo();
        switch (rshyJk.getHyType()) {
            case "pctdfk":
                map = getPctdfk(rshyParam.getSfzh(), "",rshyJk);
                rshyTypeVo.setType("pctdfk");
                if (Objects.nonNull(map)) {
                    rshyTypeVo.setMap(map);
                }
                break;
            case "pctjsry":
                map = getPctjsry(rshyParam.getSfzh(),rshyJk);
                rshyTypeVo.setType("pctjsry");
                if (Objects.nonNull(map)) {
                    rshyTypeVo.setMap(map);
                }
                break;
            case "pctxdry":
                map = getPctxdry(rshyParam.getSfzh(),rshyParam.getXm(),rshyJk);
                rshyTypeVo.setType("pctxdry");
                if (Objects.nonNull(map)) {
                    rshyTypeVo.setMap(map);
                }
                break;
            case "pctqkry":
                map = getPctqkry(rshyParam.getSfzh(),rshyJk);
                rshyTypeVo.setType("pctqkry");
                if (Objects.nonNull(map)) {
                    rshyTypeVo.setMap(map);
                }
                break;
            case "pctjkm":
                map = getPctjkm(rshyParam.getBarCode(),rshyJk);
                rshyTypeVo.setType("pctjkm");
                if (Objects.nonNull(map)) {
                    rshyTypeVo.setMap(map);
                }
                break;
            case "pctzt":
                map = getPctzt(rshyParam.getSfzh(),rshyJk);
                rshyTypeVo.setType("pctzt");
                if (Objects.nonNull(map)) {
                    rshyTypeVo.setMap(map);
                }
                break;
            case "pctzfba":
                map = getPctzfba(rshyParam.getSfzh(),rshyJk);
                rshyTypeVo.setType("pctzfba");
                if (Objects.nonNull(map)) {
                    rshyTypeVo.setMap(map);
                }
                break;
            case "pctzdry":
                map = getPctzdry(rshyParam.getSfzh(),rshyJk);
                rshyTypeVo.setType("pctzdry");
                if (Objects.nonNull(map)) {
                    rshyTypeVo.setMap(map);
                }
                break;
            default:
                break;
        }
        return rshyTypeVo;
    }


    /**
     * 打防控信息
     * @param zjhm
     * @param ajbh
     * @return
     */
    public Map<String,String> getPctdfk(String zjhm,String ajbh,RshyJk rshyJk) {
        System.out.println("请求参数"+rshyJk);
        if (StringUtils.isBlank(zjhm)) {
            return null;
        }
        Map<String,Object> map = new HashMap<>();
        map.put("appCode","pctdfk");
        map.put("apiPath","/aiss/idm_zfba_dfkajxx_df");
        map.put("apiConfig","1618208939768204,9d98c9d9d14d4d298f4408c0338c1af5,03719cc7f2fd49578e7b5ded284fdc7a.apigateway.cn-deqing-zjzfy01-zjga01.hzs.zj,HTTP");
        map.put("method","GET");
        Map<String,Object> queryMap = new HashMap<>();
        queryMap.put("zjhm",zjhm);
        queryMap.put("ajbh",ajbh);
        queryMap.put("offset",0);
        queryMap.put("count",10);
        map.put("query", queryMap);
        String post = HttpUtil.post(baseUrl, JSONObject.toJSONString(map),getInt(rshyJk.getTimeOut()));
        if (StringUtils.isBlank(post)) {
            smsRetryer(zjhm,rshyJk,null);
            return null;
        }
        log.error("返会参数{}",post);
        System.out.println("返回参数"+post);
        if (0 != rshyJk.getErrCount()) {
            rshyJk.setErrCount(0);
            rshyJk.updateById();
        }
        JSONObject jsonObject = JSONObject.parseObject(post);
        String data = jsonObject.getString("data");
        if (StringUtils.isBlank(data)) {
            return null;
        }
        List<Map<String,String>> list = JSONObject.parseObject(data, List.class);
        return list.get(0);
    }

    /**
     * 监所人员
     * @param zjhm
     * @return
     */
    public Map<String,String> getPctjsry(String zjhm,RshyJk rshyJk) {
        System.out.println("请求参数"+rshyJk);
        if (StringUtils.isBlank(zjhm)) {
            return null;
        }
        Map<String,Object> map = new HashMap<>();
        map.put("appCode","pctjsry");
        map.put("apiPath","/aiss/idm_wfcf_jsryxx_df/sql");
        map.put("apiConfig","1618208939768204,9d98c9d9d14d4d298f4408c0338c1af5,03719cc7f2fd49578e7b5ded284fdc7a.apigateway.cn-deqing-zjzfy01-zjga01.hzs.zj,HTTP");
        map.put("method","GET");
        Map<String,Object> queryMap = new HashMap<>();
        queryMap.put("zjhm",zjhm);
        queryMap.put("offset",0);
        queryMap.put("rowCount",10);
        map.put("query", queryMap);
        String post = HttpUtil.post(baseUrl, JSONObject.toJSONString(map),getInt(rshyJk.getTimeOut()));
        if (StringUtils.isBlank(post)) {
            smsRetryer(zjhm,rshyJk,null);
            return null;
        }
        log.error("返会参数{}",post);
        System.out.println("返回参数"+post);
        if (0 != rshyJk.getErrCount()) {
            rshyJk.setErrCount(0);
            rshyJk.updateById();
        }
        JSONObject jsonObject = JSONObject.parseObject(post);
        String data = jsonObject.getString("data");
        if (StringUtils.isBlank(data)) {
            return null;
        }
        List<Map<String,String>> list = JSONObject.parseObject(data, List.class);
        return list.get(0);
    }


    /**
     * 吸毒人员
     * @param zjhm
     * @return
     */
    public Map<String,String> getPctxdry(String zjhm,String xm,RshyJk rshyJk) {
        System.out.println("请求参数"+rshyJk);
        if (StringUtils.isBlank(zjhm)) {
            return null;
        }
        Map<String,Object> map = new HashMap<>();
        map.put("appCode","pctxdry");
        map.put("apiPath","/aiss/idm_zfba_xdrychjl_df/sql");
        map.put("apiConfig","1618208939768204,9d98c9d9d14d4d298f4408c0338c1af5,03719cc7f2fd49578e7b5ded284fdc7a.apigateway.cn-deqing-zjzfy01-zjga01.hzs.zj,HTTP");
        map.put("method","GET");
        Map<String,Object> queryMap = new HashMap<>();
        queryMap.put("zjid","");
        queryMap.put("xm","");
        queryMap.put("zjhm",zjhm);
        queryMap.put("zjzldm","");
        queryMap.put("zjzl","");
        queryMap.put("chrq","");
        queryMap.put("offset",0);
        queryMap.put("rowCount",10);
        map.put("query", queryMap);
        String post = HttpUtil.post(baseUrl, JSONObject.toJSONString(map),getInt(rshyJk.getTimeOut()));
        if (StringUtils.isBlank(post)) {
            smsRetryer(zjhm,rshyJk,null);
            return null;
        }
        log.error("返会参数{}",post);
        System.out.println("返回参数"+post);
        if (0 != rshyJk.getErrCount()) {
            rshyJk.setErrCount(0);
            rshyJk.updateById();
        }
        JSONObject jsonObject = JSONObject.parseObject(post);
        String data = jsonObject.getString("data");
        if (StringUtils.isBlank(data)) {
            return null;
        }
        List<Map<String,String>> list = JSONObject.parseObject(data, List.class);
        return list.get(0);
    }


    /**
     * 前科人员
     * @param zjhm
     * @return
     */
    public Map<String,String> getPctqkry(String zjhm,RshyJk rshyJk) {
        System.out.println("请求参数"+rshyJk);
        if (StringUtils.isBlank(zjhm)) {
            return null;
        }
        Map<String,Object> map = new HashMap<>();
        map.put("appCode","pctqkry");
        map.put("apiPath","/code014/ids_obj_qkryjbxx_df/sql");
        map.put("apiConfig","1618208939768204,9d98c9d9d14d4d298f4408c0338c1af5,03719cc7f2fd49578e7b5ded284fdc7a.apigateway.cn-deqing-zjzfy01-zjga01.hzs.zj,HTTP");
        map.put("method","POST_BODY");
        Map<String,Object> queryMap = new HashMap<>();
        queryMap.put("zjhm",zjhm);
        queryMap.put("offset",0);
        queryMap.put("count",10);
        map.put("query", queryMap);
        String post = HttpUtil.post(baseUrl, JSONObject.toJSONString(map),getInt(rshyJk.getTimeOut()));
        if (StringUtils.isBlank(post)) {
            smsRetryer(zjhm,rshyJk,null);
            return null;
        }
        log.error("返会参数{}",post);
        System.out.println("返回参数"+post);
        if (0 != rshyJk.getErrCount()) {
            rshyJk.setErrCount(0);
            rshyJk.updateById();
        }
        JSONObject jsonObject = JSONObject.parseObject(post);
        String data = jsonObject.getString("data");

        if (StringUtils.isBlank(data)) {
            return null;
        }
        List<Map<String,String>> list = JSONObject.parseObject(data, List.class);
        return list.get(0);
    }

    /**
     * 健康码
     * @param barCode
     * @return
     */
    public Map<String,String> getPctjkm(String barCode,RshyJk rshyJk) {
        System.out.println("健康码参数BarCode"+barCode);
        if (StringUtils.isBlank(barCode)) {
            System.out.println("barCode为空");
            return null;
        }
        Map<String,Object> map = new HashMap<>();
        map.put("appCode","pctjkm");
        map.put("apiPath","/1647590638887");
        map.put("apiConfig","1618208939768204,9d98c9d9d14d4d298f4408c0338c1af5,5cf7f9ec93964f8a86e1a819dbb54c5b.apigateway.cn-deqing-zjzfy01-zjga01.hzs.zj,HTTPS");
        map.put("method","GET");
        Map<String,String> headerMap = new HashMap<>();
        headerMap.put("APP_KEY","1618208939768204");
        headerMap.put("APP_SECRET","9d98c9d9d14d4d298f4408c0338c1af5");
        map.put("header",headerMap);
        Map<String,Object> queryMap = new HashMap<>();
        queryMap.put("bar_code",barCode);
        queryMap.put("offSet",0);
        queryMap.put("rowCount",10);
        map.put("query", queryMap);
        System.out.println("");
        String post = HttpUtil.post(baseUrl, JSONObject.toJSONString(map),getInt(rshyJk.getTimeOut()));
        System.out.println("健康码返回参数"+post);
        if (StringUtils.isBlank(post)) {
            smsRetryer(null,rshyJk,barCode);
            return null;
        }
        if (0 != rshyJk.getErrCount()) {
            rshyJk.setErrCount(0);
            rshyJk.updateById();
        }
        JSONObject jsonObject = JSONObject.parseObject(post);
        String data = jsonObject.getString("data");
        log.error("返会参数{}",post);
        if (StringUtils.isBlank(data)) {
            return null;
        }
        JSONObject dataJsonObject = JSONObject.parseObject(data);
        String result = dataJsonObject.getString("result");
        List<Map<String,String>> list = JSONObject.parseObject(result, List.class);
        return list.get(0);
    }

    /**
     * 人员劣迹
     * @param zjhm
     * @return
     */
    public Map<String,String> getPctzt(String zjhm,RshyJk rshyJk) {
        if (StringUtils.isBlank(zjhm)) {
            return null;
        }
        Map<String,Object> map = new HashMap<>();
        map.put("appCode","pctzt");
        map.put("apiPath","/aiss/dm_event_zaitao/sql");
        map.put("apiConfig","1618208939768204,9d98c9d9d14d4d298f4408c0338c1af5,03719cc7f2fd49578e7b5ded284fdc7a.apigateway.cn-deqing-zjzfy01-zjga01.hzs.zj,HTTP");
        map.put("method","GET");
        Map<String,Object> queryMap = new HashMap<>();
        queryMap.put("zjhm",zjhm);
        queryMap.put("offset",0);
        queryMap.put("count",10);
        map.put("query", queryMap);
        String post = HttpUtil.post(baseUrl, JSONObject.toJSONString(map),getInt(rshyJk.getTimeOut()));
        if (StringUtils.isBlank(post)) {
            smsRetryer(zjhm,rshyJk,null);
            return null;
        }
        if (0 != rshyJk.getErrCount()) {
            rshyJk.setErrCount(0);
            rshyJk.updateById();
        }
        JSONObject jsonObject = JSONObject.parseObject(post);
        String data = jsonObject.getString("data");
        log.error("返会参数{}",post);
        System.out.println("返回参数"+post);
        if (StringUtils.isBlank(data)) {
            return null;
        }
        List<Map<String,String>> list = JSONObject.parseObject(data, List.class);
        return list.get(0);
    }

    /**
     * 新的执法办案
     * @param zjhm
     * @return
     */
    public Map<String,String> getPctzfba(String zjhm,RshyJk rshyJk) {
        if (StringUtils.isBlank(zjhm)) {
            return null;
        }
        Map<String,Object> map = new HashMap<>();
        map.put("appCode","pctzfba");
        map.put("apiPath","/code014/idm_zfba_xbzfbaajxx_df/sql_new");
        map.put("apiConfig","1618208939768204,9d98c9d9d14d4d298f4408c0338c1af5,03719cc7f2fd49578e7b5ded284fdc7a.apigateway.cn-deqing-zjzfy01-zjga01.hzs.zj,HTTP");
        map.put("method","POST_BODY");
        Map<String,Object> queryMap = new HashMap<>();
        queryMap.put("zjhm",zjhm);
        queryMap.put("bar_zjhm","");
        queryMap.put("ajbh","ajbh");
        queryMap.put("offset",0);
        queryMap.put("count",10);
        map.put("query", queryMap);
        String post = HttpUtil.post(baseUrl, JSONObject.toJSONString(map),getInt(rshyJk.getTimeOut()));
        if (StringUtils.isBlank(post)) {
            smsRetryer(zjhm,rshyJk,null);
            return null;
        }
        log.error("返会参数{}",post);
        System.out.println("返回参数"+post);
        if (0 != rshyJk.getErrCount()) {
            rshyJk.setErrCount(0);
            rshyJk.updateById();
        }
        JSONObject jsonObject = JSONObject.parseObject(post);
        String data = jsonObject.getString("data");
        if (StringUtils.isBlank(data)) {
            return null;
        }
        List<Map<String,String>> list = JSONObject.parseObject(data, List.class);
        return list.get(0);
    }

    /**
     * 重点人员
     * @param zjhm
     * @return
     */
    public Map<String,String> getPctzdry(String zjhm,RshyJk rshyJk) {
        if (StringUtils.isBlank(zjhm)) {
            return null;
        }
        Map<String,Object> map = new HashMap<>();
        map.put("appCode","pctzdry");
        map.put("apiPath","/aiss/idm_zfba_zdryxx_df/sql");
        map.put("apiConfig","1618208939768204,9d98c9d9d14d4d298f4408c0338c1af5,03719cc7f2fd49578e7b5ded284fdc7a.apigateway.cn-deqing-zjzfy01-zjga01.hzs.zj,HTTP");
        map.put("method","POST_BODY");
        Map<String,Object> queryMap = new HashMap<>();
        queryMap.put("zjhm",zjhm);
        queryMap.put("offset",0);
        queryMap.put("count",10);
        map.put("query", queryMap);
        log.error("请求参数{}",map);
        String post = HttpUtil.post(baseUrl, JSONObject.toJSONString(map),getInt(rshyJk.getTimeOut()));
        if (StringUtils.isBlank(post)) {
            smsRetryer(zjhm,rshyJk,null);
            return null;
        }
        log.error("返会参数{}",post);
        System.out.println("返回参数"+post);
        if (0 != rshyJk.getErrCount()) {
            rshyJk.setErrCount(0);
            rshyJk.updateById();
        }
        JSONObject jsonObject = JSONObject.parseObject(post);
        String data = jsonObject.getString("data");
        if (StringUtils.isBlank(data)) {
            return null;
        }
        List<Map<String,String>> list = JSONObject.parseObject(data, List.class);
        return list.get(0);
    }

    /**
     * 重试机制
     * @param
     * @return
     */
    @Async
    public void smsRetryer (String zjhm,RshyJk rshyJk,String barCode) {
        Retryer< String> smsRetryer = RetryerBuilder.<String>newBuilder()
                // 返回的数据是null要重试
                .retryIfResult(Predicates.<String>isNull())
                // 返回的异常错误类
                .retryIfExceptionOfType(IOException.class)
                //每次重试之间间隔三秒
                .withWaitStrategy(WaitStrategies.fixedWait(3, TimeUnit.SECONDS))
                //最大重试次数，当达到这个次数则抛出ExecutionException异常
                .withStopStrategy(StopStrategies.stopAfterAttempt(3))
                .build();
        Callable<String> callable = new Callable<String>() {
            @Override
            public String call() throws Exception {
                return getMap(zjhm,rshyJk,barCode);
            }
        };
        String result = null;
        try {
            result = smsRetryer.call(callable);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("同步数据异常",e);
        }
        if (StringUtils.isBlank(result)) {
            rshyJk.setErrCount(1);
        } else {
            rshyJk.setErrCount(0);
        }
        rshyJk.updateById();
    }

    /**
     * 重试请求接口
     * @param zjhm
     * @param rshyJk
     * @param barCode
     * @return
     */
    public String getMap(String zjhm,RshyJk rshyJk,String barCode) {
        Map<String, Object> map = new ConcurrentHashMap<>();
        switch (rshyJk.getHyType()) {
            case "pctdfk":
                map.put("appCode","pctdfk");
                map.put("apiPath","/aiss/idm_zfba_dfkajxx_df");
                map.put("apiConfig","1618208939768204,9d98c9d9d14d4d298f4408c0338c1af5,03719cc7f2fd49578e7b5ded284fdc7a.apigateway.cn-deqing-zjzfy01-zjga01.hzs.zj,HTTP");
                map.put("method","GET");
                Map<String,Object> queryMap = new HashMap<>();
                queryMap.put("zjhm",zjhm);
                queryMap.put("ajbh","");
                queryMap.put("offset",0);
                queryMap.put("count",10);
                map.put("query", queryMap);
                break;
            case "pctjsry":
                map.put("appCode","pctjsry");
                map.put("apiPath","/aiss/idm_wfcf_jsryxx_df/sql");
                map.put("apiConfig","1618208939768204,9d98c9d9d14d4d298f4408c0338c1af5,03719cc7f2fd49578e7b5ded284fdc7a.apigateway.cn-deqing-zjzfy01-zjga01.hzs.zj,HTTP");
                map.put("method","GET");
                Map<String,Object> queryMap1 = new HashMap<>();
                queryMap1.put("zjhm",zjhm);
                queryMap1.put("offset",0);
                queryMap1.put("rowCount",10);
                map.put("query", queryMap1);
                break;
            case "pctxdry":
                map.put("appCode","pctxdry");
                map.put("apiPath","/aiss/idm_zfba_xdrychjl_df/sql");
                map.put("apiConfig","1618208939768204,9d98c9d9d14d4d298f4408c0338c1af5,03719cc7f2fd49578e7b5ded284fdc7a.apigateway.cn-deqing-zjzfy01-zjga01.hzs.zj,HTTP");
                map.put("method","GET");
                Map<String,Object> queryMap2 = new HashMap<>();
                queryMap2.put("zjid","");
                queryMap2.put("xm","");
                queryMap2.put("zjhm",zjhm);
                queryMap2.put("zjzldm","");
                queryMap2.put("zjzl","");
                queryMap2.put("chrq","");
                queryMap2.put("offset",0);
                queryMap2.put("rowCount",10);
                map.put("query", queryMap2);
                break;
            case "pctqkry":
                map.put("appCode","pctqkry");
                map.put("apiPath","/code014/ids_obj_qkryjbxx_df/sql");
                map.put("apiConfig","1618208939768204,9d98c9d9d14d4d298f4408c0338c1af5,03719cc7f2fd49578e7b5ded284fdc7a.apigateway.cn-deqing-zjzfy01-zjga01.hzs.zj,HTTP");
                map.put("method","POST_BODY");
                Map<String,Object> queryMap3 = new HashMap<>();
                queryMap3.put("zjhm",zjhm);
                queryMap3.put("offset",0);
                queryMap3.put("count",10);
                map.put("query", queryMap3);
                break;
            case "pctjkm":
                map.put("appCode","pctjkm");
                map.put("apiPath","/1647590638887");
                map.put("apiConfig","1618208939768204,9d98c9d9d14d4d298f4408c0338c1af5,5cf7f9ec93964f8a86e1a819dbb54c5b.apigateway.cn-deqing-zjzfy01-zjga01.hzs.zj,HTTPS");
                map.put("method","GET");
                Map<String,Object> queryMap4 = new HashMap<>();
                queryMap4.put("bar_code",barCode);
                queryMap4.put("offSet",0);
                queryMap4.put("count",10);
                map.put("query", queryMap4);
                break;
            case "pctzt":
                map.put("appCode","pctzt");
                map.put("apiPath","/aiss/dm_event_zaitao/sql");
                map.put("apiConfig","1618208939768204,9d98c9d9d14d4d298f4408c0338c1af5,03719cc7f2fd49578e7b5ded284fdc7a.apigateway.cn-deqing-zjzfy01-zjga01.hzs.zj,HTTP");
                map.put("method","GET");
                Map<String,Object> queryMap5 = new HashMap<>();
                queryMap5.put("zjhm",zjhm);
                queryMap5.put("offset",0);
                queryMap5.put("count",10);
                map.put("query", queryMap5);
                break;
            case "pctzfba":
                map.put("appCode","pctzfba");
                map.put("apiPath","/code014/idm_zfba_xbzfbaajxx_df/sql_new");
                map.put("apiConfig","1618208939768204,9d98c9d9d14d4d298f4408c0338c1af5,03719cc7f2fd49578e7b5ded284fdc7a.apigateway.cn-deqing-zjzfy01-zjga01.hzs.zj,HTTP");
                map.put("method","POST_BODY");
                Map<String,Object> queryMap7 = new HashMap<>();
                queryMap7.put("zjhm",zjhm);
                queryMap7.put("bar_zjhm","");
                queryMap7.put("ajbh","ajbh");
                queryMap7.put("offset",0);
                queryMap7.put("count",10);
                map.put("query", queryMap7);
                break;
            case "pctzdry":
                map.put("appCode","pctzdry");
                map.put("apiPath","/aiss/idm_zfba_zdryxx_df/sql");
                map.put("apiConfig","1618208939768204,9d98c9d9d14d4d298f4408c0338c1af5,03719cc7f2fd49578e7b5ded284fdc7a.apigateway.cn-deqing-zjzfy01-zjga01.hzs.zj,HTTP");
                map.put("method","POST_BODY");
                Map<String,Object> queryMap8 = new HashMap<>();
                queryMap8.put("zjhm",zjhm);
                queryMap8.put("offset",0);
                queryMap8.put("count",10);
                map.put("query", queryMap8);
                break;
            default:
                break;
        }
        String post = HttpUtil.post(baseUrl, JSONObject.toJSONString(map),getInt(rshyJk.getTimeOut()));
        if (StringUtils.isBlank(post)) {
            return null;
        }
        return post;
    }

    @Scheduled(cron = "0 0/10 * * * ?")
    public void taskRshy() {
        log.error("进入定时");
        List<RshyJk> rshyError = rshyJkService.getRshyError();
        if (CollectionUtils.isEmpty(rshyError)) {
            return;
        }
        rshyError.forEach(rshyJk -> {
            String map = getMap("412728199706030513", rshyJk, "ff70eae2e37a6e6ce7ff34d0a9e92f5d");
            if (StringUtils.isNotBlank(map)) {
                rshyJk.setErrCount(0);
                rshyJk.updateById();
            }
        });
    }

    /**
     * 人车核验
     * @return
     */
    public String getRchy(String xm,String sfzh) {
        // 创建一个请求头对象
        HttpHeaders headers = new HttpHeaders();
        MediaType type = MediaType.parseMediaType("text/xml;charset=UTF-8");
        // 设置请求头对象contentTyp的为text/xml;charset=UTF-8
        headers.setContentType(type);


        // 将请求参数进行封装并进行远程接口服务调用
        // 构造webservice请求参数
        StringBuffer soapRequestData = new StringBuffer("");
        soapRequestData.append(
                    "<soapenv:Envelope xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" xmlns:xsd=\"http://www.w3.org/2001/XMLSchema\" xmlns:soapenv=\"http://schemas.xmlsoap.org/soap/envelope/\" xmlns:act=\"action.rchl.thunis.com\">");
        soapRequestData.append("<soapenv:Header/>");
        soapRequestData.append("<soapenv:Body>");
        soapRequestData.append("</soapenv:Body>");
        soapRequestData.append("<act:rchlRyhc soapenv:encodingStyle=\"http://schemas.xmlsoap.org/soap/encoding/\">");
        soapRequestData.append("<senderID xsi:type=\"soapenc:string\" xmlns:soapenc=\"http://schemas.xmlsoap.org/soap/encoding/\">");
        soapRequestData.append("8882");
        soapRequestData.append("</senderID>");
        soapRequestData.append("<hcbb xsi:type=\"soapenc:string\" xmlns:soapenc=\"http://schemas.xmlsoap.org/soap/encoding/\">");
        soapRequestData.append("02");
        soapRequestData.append("</hcbb>");
        soapRequestData.append("<info xsi:type=\"act:ArrayOfArrayOf_soapenc_string\" soapenc:arrayType=\"soapenc:string[][]\" xmlns:soapenc=\"http://schemas.xmlsoap.org/soap/encoding/\"/>");
        String [][] info={{"XM","SFZH","SJHM","JGDM","ZSBH","DLIP","HCDZ","HCJD","HCWD"},{""}};
        soapRequestData.append(info);
        soapRequestData.append("</info>");
        soapRequestData.append("</act:rchlRyhc>");
        soapRequestData.append("</soapenv:Envelope>");
        // 创建请求
        HttpEntity<String> request = new HttpEntity<String>(soapRequestData + "", headers);

        // 发送post请求并获取到响应结果
        String str = null;
        // 封装一下返回结果
        Map<String, Object> analyseResult = new HashMap<String, Object>();
        String post = "";
        try {
             post = HttpUtil.post("http://10.118.9.243:9081/zdry/services/Bjch", JSONObject.toJSONString(request));
        } catch (Exception e) {
              e.printStackTrace();
        }
        return post;


    }

    private Integer getInt(String time) {
        BigDecimal multiply = BigDecimal.valueOf(Long.parseLong(time)).multiply(BigDecimal.valueOf(1000L));
        return multiply.intValue();
    }


}
